@@ -4,7 +4,7 @@ from .. import layers
 from .. import parameters
 from ..subnetworks import achain
 
-from .network_utils import get_signature, get_named_layers
+from .utils import get_signature, get_named_layers
 
 __all__ = [
   'Network', 'network',
@@ -108,7 +108,6 @@ class Network(object):
       else:
         raise
 
-
   def mode(self, **modes):
     if len(modes) == 0:
       return self
