@@ -9,9 +9,7 @@ __all__ = [
 ]
 
 class DecompositionParameter(Parameter):
-  def __init__(self, shape, n, w1=default_weight_init, w2=default_weight_init, properties=None, name=None):
-    properties = dict() if properties is None else properties
-
+  def __init__(self, shape, n, w1=default_weight_init, w2=default_weight_init, name=None, **properties):
     shape1 = (shape[0], n) + shape[2:]
     shape2 = (n, shape[1]) + shape[2:]
 
@@ -32,7 +30,8 @@ class DecompositionParameter(Parameter):
 
     super(DecompositionParameter, self).__init__(
       self.w1, self.w2,
-      shape=shape, properties=properties, name=name
+      shape=shape, name=name,
+      **properties
     )
 
   def get_output_for(self, w1, w2):
@@ -43,4 +42,4 @@ class DecompositionParameter(Parameter):
     assert w1_shape[2:] == w2_shape[2:], 'parameters shapes are not compatible'
     return (w1_shape[0], w2_shape[1]) + w1_shape[2:]
 
-decomposition = parameter_model(DecompositionParameter, composite=True)
\ No newline at end of file
+decomposition = parameter_model(DecompositionParameter, composite=True)()
\ No newline at end of file
