@@ -1,11 +1,11 @@
 import tensorflow as tf
-from .meta import as_free_parameter
+from .meta import as_free_parameter, parameter_model
 
 __all__ = [
   'glorot_scaling',
-  'glorot_normal_init',
-  'glorot_uniform_init',
-  'glorot_normal_double_init',
+  'GlorotNormalInit', 'glorot_normal_init',
+  'GlorotUniformInit', 'glorot_uniform_init',
+  'GlorotNormalDoubleInit', 'glorot_normal_double_init',
 ]
 
 def glorot_scaling(shape, gain=1.0):
@@ -27,8 +27,11 @@ def _double_glorot_normal(shape, target_shape, gain=1.0, dtype=tf.float32, name=
   return _glorot_normal(shape, gain=gain, dtype=dtype, name=name)
 
 
-glorot_normal_init = as_free_parameter(_glorot_normal)
-glorot_normal_double_init = as_free_parameter(_double_glorot_normal)
+GlorotNormalInit = as_free_parameter(_glorot_normal)
+glorot_normal_init = parameter_model(GlorotNormalInit)()
+
+GlorotNormalDoubleInit = as_free_parameter(_double_glorot_normal)
+glorot_normal_double_init = parameter_model(GlorotNormalDoubleInit)()
 
 
 def _glorot_uniform(shape, gain=1.0, dtype=tf.float32, name=None):
@@ -42,4 +45,5 @@ def _glorot_uniform(shape, gain=1.0, dtype=tf.float32, name=None):
 
     return tf.random.uniform(shape=shape, minval=-scale, maxval=scale, dtype=dtype, name=name)
 
-glorot_uniform_init = as_free_parameter(_glorot_uniform)
\ No newline at end of file
+GlorotUniformInit = as_free_parameter(_glorot_uniform)
+glorot_uniform_init = parameter_model(GlorotUniformInit)()
\ No newline at end of file
