@@ -1,6 +1,4 @@
-import tensorflow as tf
-
-from .common import glorot_normal_init
+from .defaults import default_weight_init
 from .meta import Parameter, parameter_model
 
 __all__ = [
@@ -8,7 +6,7 @@ __all__ = [
 ]
 
 class MaskedParameter(Parameter):
-  def __init__(self, shape, mask, w=glorot_normal_init(), properties=None, name=None):
+  def __init__(self, shape, mask, w=default_weight_init(), name=None, **properties):
     self.w = w(
       shape=shape,
       **properties,
@@ -25,8 +23,8 @@ class MaskedParameter(Parameter):
     super(MaskedParameter, self).__init__(
       self.w, self.mask,
       shape=shape,
-      properties=properties,
-      name=name
+      name=name,
+      **properties
     )
 
   def get_output_for(self, w, mask):
@@ -36,4 +34,4 @@ class MaskedParameter(Parameter):
     assert w_shape == mask_shape
     return w_shape
 
-masked = parameter_model(MaskedParameter)
\ No newline at end of file
+masked = parameter_model(MaskedParameter, masked=True)()
\ No newline at end of file
