@@ -4,12 +4,11 @@ from .meta import Parameter, parameter_model
 from .defaults import default_weight_init
 
 __all__ = [
-  'NoisyParameter',
-  'noisy_parameter'
+  'NoisyParameter', 'noisy_parameter'
 ]
 
 class NoisyParameter(Parameter):
-  def __init__(self, shape, eps=1e-3, w=default_weight_init, name=None, properties=None):
+  def __init__(self, shape, eps=1e-3, w=default_weight_init, name=None, **properties):
     self.eps = tf.constant(eps, dtype=tf.float32, shape=())
 
     self.w = w(
@@ -18,8 +17,8 @@ class NoisyParameter(Parameter):
     )
 
     super(NoisyParameter, self).__init__(
-      w,
-      shape=shape, properties=properties, name=name
+      self.w, shape=shape, name=name,
+      **properties
     )
 
   def get_output_for(self, w, deterministic=False):
@@ -31,4 +30,4 @@ class NoisyParameter(Parameter):
   def get_output_shape_for(self, w_shape):
     return w_shape
 
-noisy_parameter = parameter_model(NoisyParameter)
+noisy_parameter = parameter_model(NoisyParameter)()
