@@ -10,14 +10,14 @@ __all__ = [
 ]
 
 class SoftmaxParameter(Parameter):
-  def __init__(self, shape, scale=1, w=zeros_init(), properties=None, name=None):
+  def __init__(self, shape, scale=1, w=zeros_init(), name=None, **properties):
     self.scale = None if scale == 1 else tf.constant(scale, dtype=tf.float32)
 
     self.w = w(shape=shape, **properties, name=(name + '_w') if name is not None else None)
 
     super(SoftmaxParameter, self).__init__(
-      self.w,
-      shape=shape, properties=properties, name=name
+      self.w, shape=shape, name=name,
+      **properties
     )
 
   def get_output_for(self, w):
@@ -30,16 +30,16 @@ class SoftmaxParameter(Parameter):
   def get_output_shape_for(self, w_shape):
     return w_shape
 
-softmax_parameter = parameter_model(SoftmaxParameter)
+softmax_parameter = parameter_model(SoftmaxParameter)()
 
 
 class SoftplusParameter(Parameter):
-  def __init__(self, shape, w=glorot_normal_init(gain=0.5), properties=None, name=None):
+  def __init__(self, shape, w=glorot_normal_init(gain=0.5), name=None, **properties):
     self.w = w(shape=shape, **properties, name=(name + '_w') if name is not None else None)
 
     super(SoftplusParameter, self).__init__(
-      self.w,
-      shape=shape, properties=properties, name=name
+      self.w, shape=shape, name=name,
+      **properties
     )
 
   def get_output_for(self, w):
@@ -48,4 +48,4 @@ class SoftplusParameter(Parameter):
   def get_output_shape_for(self, w_shape):
     return w_shape
 
-softplus_parameter = parameter_model(SoftplusParameter)
\ No newline at end of file
+softplus_parameter = parameter_model(SoftplusParameter)()
\ No newline at end of file
