@@ -1,14 +1,10 @@
-from craygraph.graph import graph_lang
+from craygraph.graph import *
 
 __all__ = [
   'achain', 'repeat', 'with_inputs', 'select', 'seek', 'nothing',
   'subnetwork'
 ]
 
-lang = graph_lang()
-achain, repeat = lang.achain, lang.repeat
-nothing, with_inputs, select, seek = lang.nothing, lang.with_inputs, lang.select, lang.seek
-
 def subnetwork(inputs, outputs):
   """
   Applies existing graph substituting inputs by a new set of incoming layers.
