@@ -11,27 +11,21 @@ __all__ = [
 
 class SlicedSubset(VariableDataset):
   def __init__(self, dataset : Dataset, item : slice or int):
-    item = tuple(slice(None, None, None) for _ in range(dataset.axis)) + (item,)
-
     super(SlicedSubset, self).__init__(*[
       d[item] for d in dataset._data()
-    ], axis=dataset.axis)
+    ], seed=dataset.rng)
 
 class IndexedSubset(Dataset):
   def __init__(self, dataset : Dataset, indx):
     self.indx = tf.convert_to_tensor(indx)
     self.dataset = dataset
 
-    super(IndexedSubset, self).__init__(self.dataset.axis, singular=dataset._singular)
+    super(IndexedSubset, self).__init__(seed=dataset.rng)
 
   def _get_single(self, item):
-    item = tuple(slice(None, None, None) for _ in range(self.axis)) + (item,)
-
     return self.dataset._get_single(self.indx[item])
 
   def _get_slice(self, item):
-    item = tuple(slice(None, None, None) for _ in range(self.axis)) + (item,)
-
     indx = self.indx[item]
 
     return self.dataset._get_sparse(indx)
@@ -56,6 +50,6 @@ class IndexedSubset(Dataset):
   def shapes(self):
     size = self.size()
     return tuple(
-      shape[:self.axis] + (size,) + shape[(self.axis + 1):]
+      (size, ) + shape[1:]
       for shape in self.dataset.shapes()
     )
\ No newline at end of file
